Missionary from Oregon pleads not guilty to sexual conduct with boy in Cambodia | OregonLive.com
Description: Daniel S. Johnson, who spent a year in a Cambodian jail for molesting boys at an orphanage, had once been accused of molesting children in Lincoln County.

comments

# Missionary from Oregon pleads not guilty to sexual conduct with boy in Cambodia

WayneMorseUSCthouse.jpg
The Wayne Morse U.S. Courthouse was dedicated in 2006. (Oregonian file photo)
Print
Bryan Denson | bdenson@oregonian.com By Bryan Denson | bdenson@oregonian.com The Oregonian
Email the author | Follow on Twitter
on December 29, 2014 at 3:21 PM, updated December 29, 2014 at 4:11 PM
View/Post Comments

A 36-year-old part-time missionary who served a year in a Cambodian prison for sexually abusing boys in an orphanage pleaded not guilty on Monday in a Eugene courtroom to a rarely imposed federal charge of engaging in illicit sexual conduct in a foreign place.

Daniel Stephen Johnson faces a potential 30-year prison term on the new charge, which accuses him of having sex with a boy in the Kingdom of Cambodia sometime between Nov. 28, 2005, and Oct. 12, 2006.

View full size Daniel S. JohnsonLane County Jail

U.S. Magistrate Judge Thomas Coffin set Johnson's trial for Feb. 25.

A federal grand jury indicted Johnson on Dec. 10. He's awaiting trial in the Lane County Jail.

Johnson served a one-year sentence in Cambodia for sexually abusing boys in his care at an orphanage, The Register-Guard newspaper reported. He worked as a Christian missionary in the Southeast Asian country for about a decade, according to the Cambodia-based anti-pedophile group Action pour les Enfants.

A 2003 federal law aimed at preventing child abuse made it a crime for any U.S. citizen to have illegal sexual contact with a minor in a foreign country.

More than a decade ago, Johnson was accused in Oregon of molesting three children in his sister's care.

Lincoln County prosecutors dismissed charges after investigators began to doubt the alleged victims' statements, according to a 2003 article in the Yamhill Valley News-Register.

-- Bryan Denson

View/Post Comments

## Related Stories

## Most Read

# Photo of the Day

## Portland's Central Eastside Industrial District

» More videos & photos

## Active Discussions

# News Videos

## Best of OregonLive.com

26 dead in Portland homicides in 2014
Faces of Meth, 10 years later
Top 2014 restaurant, bar openings in Portland